@@ -1,15 +1,33 @@
 from datetime import datetime
 from enum import Enum
-from typing import Optional, Union
+from typing import Any, Dict, Optional, Union
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, SecretStr
+
+from ..log import STDOUT
+
+
+class ProcessAccount(BaseModel):
+    uin: int
+    password: Optional[SecretStr] = None
+    config: Dict[str, Any] = Field(default_factory=dict)
+    device: Dict[str, Any] = Field(default_factory=dict)
+
+
+class ProcessLogLevel(str, Enum):
+    STDOUT = STDOUT.name
+
+    DEBUG = "DEBUG"
+    INFO = "INFO"
+    WARNING = "WARNING"
+    ERROR = "ERROR"
+    FATAL = "FATAL"
 
 
 class ProcessLog(BaseModel):
-    raw: str
     time: datetime = Field(default_factory=datetime.now)
-    level: Optional[str] = None
-    message: Optional[str] = None
+    level: ProcessLogLevel = ProcessLogLevel.STDOUT
+    message: str
 
 
 class ProcessStatus(str, Enum):
